@@ -1,3 +1,4 @@
+from PyQt5.QtGui import QPalette
 from PyQt5.QtWidgets import QWidget
 from pyqt_titlebar_buttons_widget import TitlebarButtonsWidget
 
@@ -12,6 +13,11 @@ class WindowsButtonsWidget(TitlebarButtonsWidget):
         self._maximizeBtn.setText('🗖')
         self._closeBtn.setText('🗙')
 
+        # fill the button's background with color
+        background_color = self._base_widget.palette().color(QPalette.Base).name()
+        for btn in self._btn_dict.values():
+            btn.setBackground(background_color)
+
         self.__styleInit()
 
     def __styleInit(self):
@@ -21,6 +27,10 @@ class WindowsButtonsWidget(TitlebarButtonsWidget):
                              background-color: #EE0000; 
                              color: #ffffff;
                              }}
+                             QPushButton:pressed
+                             {{
+                             background-color: #CC0000;
+                             }}
                              '''
 
         self._closeBtn.setStyleSheet(close_button_style)
